EasyExtend.langlets.p4d.xmlutils.ExpatParser

Package EasyExtend :: Package langlets :: Package p4d :: Module xmlutils :: Class ExpatParser |
[hide private]
[frames] | no frames]

# Class ExpatParser

    object --+
             |
        Parser --+
                 |
                ExpatParser

Instance Methods | [hide private]
_create_parser(self) |
Inherited from `Parser`: `__init__`, `char_data`, `comment`, `default`, `end_cdata`, `end_element`, `parse`, `start_cdata`, `start_element` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`